bestParamSets.RdThe n distinct members of the final population with the lowest replicated mean
(fireSenseUtils::runDEoptim() attaches the re-score as attr(DE, "finalRescore")). Without a
re-score, the final population's own values are used. Not the n generations with the lowest best
value: those are copies of one, usually lucky, member.
bestParamSets(DE, parNames, n = 5L)list of DEoptim objects returned by fireSenseUtils::runDEoptim().
character; parameter names, in the order of the columns of the population.
integer; number of parameter sets to return.
list: params (matrix, one row per set) and objFunVal (their objective values), as
returned by fireSenseUtils::bestByReplicatedMean().